<?php

namespace Litecms\Forever\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Forever\Models\Forvever;

class ForveverPolicy
{

    /**
     * Determine if the given user can view the forvever.
     *
     * @param UserPolicy $user
     * @param Forvever $forvever
     *
     * @return bool
     */
    public function view(UserPolicy $user, Forvever $forvever)
    {
        if ($user->canDo('forever.forvever.view') && $user->isAdmin()) {
            return true;
        }

        return $forvever->user_id == user_id() && $forvever->user_type == user_type();
    }

    /**
     * Determine if the given user can create a forvever.
     *
     * @param UserPolicy $user
     * @param Forvever $forvever
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('forever.forvever.create');
    }

    /**
     * Determine if the given user can update the given forvever.
     *
     * @param UserPolicy $user
     * @param Forvever $forvever
     *
     * @return bool
     */
    public function update(UserPolicy $user, Forvever $forvever)
    {
        if ($user->canDo('forever.forvever.edit') && $user->isAdmin()) {
            return true;
        }

        return $forvever->user_id == user_id() && $forvever->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given forvever.
     *
     * @param UserPolicy $user
     * @param Forvever $forvever
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Forvever $forvever)
    {
        return $forvever->user_id == user_id() && $forvever->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given forvever.
     *
     * @param UserPolicy $user
     * @param Forvever $forvever
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Forvever $forvever)
    {
        if ($user->canDo('forever.forvever.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given forvever.
     *
     * @param UserPolicy $user
     * @param Forvever $forvever
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Forvever $forvever)
    {
        if ($user->canDo('forever.forvever.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
